# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class PostProcessingOverview(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'username': 'str',
        'metadata_version': 'str',
        'start_time_sim': 'str',
        'end_time_sim': 'str',
        'results': 'Result',
        'settings': 'Settings',
        'model_name': 'str',
        'simulation_name': 'str',
        'scenario_name': 'str',
        'model_id': 'int',
        'model_revision_id': 'str',
        'email': 'str',
        'result_uuid': 'str',
        'organisation_uuid': 'str',
        'simulation': 'int'
    }

    attribute_map = {
        'username': 'username',
        'metadata_version': 'metadata_version',
        'start_time_sim': 'start_time_sim',
        'end_time_sim': 'end_time_sim',
        'results': 'results',
        'settings': 'settings',
        'model_name': 'model_name',
        'simulation_name': 'simulation_name',
        'scenario_name': 'scenario_name',
        'model_id': 'model_id',
        'model_revision_id': 'model_revision_id',
        'email': 'email',
        'result_uuid': 'result_uuid',
        'organisation_uuid': 'organisation_uuid',
        'simulation': 'simulation'
    }

    def __init__(self, username=None, metadata_version='1.2', start_time_sim=None, end_time_sim=None, results=None, settings=None, model_name=None, simulation_name=None, scenario_name=None, model_id=None, model_revision_id=None, email=None, result_uuid=None, organisation_uuid=None, simulation=None, local_vars_configuration=None):  # noqa: E501
        """PostProcessingOverview - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._username = None
        self._metadata_version = None
        self._start_time_sim = None
        self._end_time_sim = None
        self._results = None
        self._settings = None
        self._model_name = None
        self._simulation_name = None
        self._scenario_name = None
        self._model_id = None
        self._model_revision_id = None
        self._email = None
        self._result_uuid = None
        self._organisation_uuid = None
        self._simulation = None
        self.discriminator = None

        if username is not None:
            self.username = username
        if metadata_version is not None:
            self.metadata_version = metadata_version
        if start_time_sim is not None:
            self.start_time_sim = start_time_sim
        if end_time_sim is not None:
            self.end_time_sim = end_time_sim
        self.results = results
        self.settings = settings
        if model_name is not None:
            self.model_name = model_name
        if simulation_name is not None:
            self.simulation_name = simulation_name
        if scenario_name is not None:
            self.scenario_name = scenario_name
        if model_id is not None:
            self.model_id = model_id
        if model_revision_id is not None:
            self.model_revision_id = model_revision_id
        if email is not None:
            self.email = email
        if result_uuid is not None:
            self.result_uuid = result_uuid
        if organisation_uuid is not None:
            self.organisation_uuid = organisation_uuid
        if simulation is not None:
            self.simulation = simulation

    @property
    def username(self):
        """Gets the username of this PostProcessingOverview.  # noqa: E501


        :return: The username of this PostProcessingOverview.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this PostProcessingOverview.


        :param username: The username of this PostProcessingOverview.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def metadata_version(self):
        """Gets the metadata_version of this PostProcessingOverview.  # noqa: E501


        :return: The metadata_version of this PostProcessingOverview.  # noqa: E501
        :rtype: str
        """
        return self._metadata_version

    @metadata_version.setter
    def metadata_version(self, metadata_version):
        """Sets the metadata_version of this PostProcessingOverview.


        :param metadata_version: The metadata_version of this PostProcessingOverview.  # noqa: E501
        :type: str
        """

        self._metadata_version = metadata_version

    @property
    def start_time_sim(self):
        """Gets the start_time_sim of this PostProcessingOverview.  # noqa: E501


        :return: The start_time_sim of this PostProcessingOverview.  # noqa: E501
        :rtype: str
        """
        return self._start_time_sim

    @start_time_sim.setter
    def start_time_sim(self, start_time_sim):
        """Sets the start_time_sim of this PostProcessingOverview.


        :param start_time_sim: The start_time_sim of this PostProcessingOverview.  # noqa: E501
        :type: str
        """

        self._start_time_sim = start_time_sim

    @property
    def end_time_sim(self):
        """Gets the end_time_sim of this PostProcessingOverview.  # noqa: E501


        :return: The end_time_sim of this PostProcessingOverview.  # noqa: E501
        :rtype: str
        """
        return self._end_time_sim

    @end_time_sim.setter
    def end_time_sim(self, end_time_sim):
        """Sets the end_time_sim of this PostProcessingOverview.


        :param end_time_sim: The end_time_sim of this PostProcessingOverview.  # noqa: E501
        :type: str
        """

        self._end_time_sim = end_time_sim

    @property
    def results(self):
        """Gets the results of this PostProcessingOverview.  # noqa: E501


        :return: The results of this PostProcessingOverview.  # noqa: E501
        :rtype: Result
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this PostProcessingOverview.


        :param results: The results of this PostProcessingOverview.  # noqa: E501
        :type: Result
        """
        if self.local_vars_configuration.client_side_validation and results is None:  # noqa: E501
            raise ValueError("Invalid value for `results`, must not be `None`")  # noqa: E501

        self._results = results

    @property
    def settings(self):
        """Gets the settings of this PostProcessingOverview.  # noqa: E501


        :return: The settings of this PostProcessingOverview.  # noqa: E501
        :rtype: Settings
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this PostProcessingOverview.


        :param settings: The settings of this PostProcessingOverview.  # noqa: E501
        :type: Settings
        """
        if self.local_vars_configuration.client_side_validation and settings is None:  # noqa: E501
            raise ValueError("Invalid value for `settings`, must not be `None`")  # noqa: E501

        self._settings = settings

    @property
    def model_name(self):
        """Gets the model_name of this PostProcessingOverview.  # noqa: E501


        :return: The model_name of this PostProcessingOverview.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this PostProcessingOverview.


        :param model_name: The model_name of this PostProcessingOverview.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    @property
    def simulation_name(self):
        """Gets the simulation_name of this PostProcessingOverview.  # noqa: E501


        :return: The simulation_name of this PostProcessingOverview.  # noqa: E501
        :rtype: str
        """
        return self._simulation_name

    @simulation_name.setter
    def simulation_name(self, simulation_name):
        """Sets the simulation_name of this PostProcessingOverview.


        :param simulation_name: The simulation_name of this PostProcessingOverview.  # noqa: E501
        :type: str
        """

        self._simulation_name = simulation_name

    @property
    def scenario_name(self):
        """Gets the scenario_name of this PostProcessingOverview.  # noqa: E501

        Scenario name for saving the results  # noqa: E501

        :return: The scenario_name of this PostProcessingOverview.  # noqa: E501
        :rtype: str
        """
        return self._scenario_name

    @scenario_name.setter
    def scenario_name(self, scenario_name):
        """Sets the scenario_name of this PostProcessingOverview.

        Scenario name for saving the results  # noqa: E501

        :param scenario_name: The scenario_name of this PostProcessingOverview.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                scenario_name is not None and len(scenario_name) < 1):
            raise ValueError("Invalid value for `scenario_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._scenario_name = scenario_name

    @property
    def model_id(self):
        """Gets the model_id of this PostProcessingOverview.  # noqa: E501


        :return: The model_id of this PostProcessingOverview.  # noqa: E501
        :rtype: int
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this PostProcessingOverview.


        :param model_id: The model_id of this PostProcessingOverview.  # noqa: E501
        :type: int
        """

        self._model_id = model_id

    @property
    def model_revision_id(self):
        """Gets the model_revision_id of this PostProcessingOverview.  # noqa: E501


        :return: The model_revision_id of this PostProcessingOverview.  # noqa: E501
        :rtype: str
        """
        return self._model_revision_id

    @model_revision_id.setter
    def model_revision_id(self, model_revision_id):
        """Sets the model_revision_id of this PostProcessingOverview.


        :param model_revision_id: The model_revision_id of this PostProcessingOverview.  # noqa: E501
        :type: str
        """

        self._model_revision_id = model_revision_id

    @property
    def email(self):
        """Gets the email of this PostProcessingOverview.  # noqa: E501


        :return: The email of this PostProcessingOverview.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this PostProcessingOverview.


        :param email: The email of this PostProcessingOverview.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def result_uuid(self):
        """Gets the result_uuid of this PostProcessingOverview.  # noqa: E501


        :return: The result_uuid of this PostProcessingOverview.  # noqa: E501
        :rtype: str
        """
        return self._result_uuid

    @result_uuid.setter
    def result_uuid(self, result_uuid):
        """Sets the result_uuid of this PostProcessingOverview.


        :param result_uuid: The result_uuid of this PostProcessingOverview.  # noqa: E501
        :type: str
        """

        self._result_uuid = result_uuid

    @property
    def organisation_uuid(self):
        """Gets the organisation_uuid of this PostProcessingOverview.  # noqa: E501


        :return: The organisation_uuid of this PostProcessingOverview.  # noqa: E501
        :rtype: str
        """
        return self._organisation_uuid

    @organisation_uuid.setter
    def organisation_uuid(self, organisation_uuid):
        """Sets the organisation_uuid of this PostProcessingOverview.


        :param organisation_uuid: The organisation_uuid of this PostProcessingOverview.  # noqa: E501
        :type: str
        """

        self._organisation_uuid = organisation_uuid

    @property
    def simulation(self):
        """Gets the simulation of this PostProcessingOverview.  # noqa: E501


        :return: The simulation of this PostProcessingOverview.  # noqa: E501
        :rtype: int
        """
        return self._simulation

    @simulation.setter
    def simulation(self, simulation):
        """Sets the simulation of this PostProcessingOverview.


        :param simulation: The simulation of this PostProcessingOverview.  # noqa: E501
        :type: int
        """

        self._simulation = simulation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PostProcessingOverview):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PostProcessingOverview):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class InpyVersion(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'url': 'str',
        'threedi_version': 'str',
        'threedicore_version': 'str',
        'slug': 'str',
        'id': 'int',
        'active': 'bool'
    }

    attribute_map = {
        'url': 'url',
        'threedi_version': 'threedi_version',
        'threedicore_version': 'threedicore_version',
        'slug': 'slug',
        'id': 'id',
        'active': 'active'
    }

    def __init__(self, url=None, threedi_version=None, threedicore_version=None, slug=None, id=None, active=None, local_vars_configuration=None):  # noqa: E501
        """InpyVersion - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._url = None
        self._threedi_version = None
        self._threedicore_version = None
        self._slug = None
        self._id = None
        self._active = None
        self.discriminator = None

        if url is not None:
            self.url = url
        self.threedi_version = threedi_version
        self.threedicore_version = threedicore_version
        if slug is not None:
            self.slug = slug
        if id is not None:
            self.id = id
        if active is not None:
            self.active = active

    @property
    def url(self):
        """Gets the url of this InpyVersion.  # noqa: E501


        :return: The url of this InpyVersion.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this InpyVersion.


        :param url: The url of this InpyVersion.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def threedi_version(self):
        """Gets the threedi_version of this InpyVersion.  # noqa: E501


        :return: The threedi_version of this InpyVersion.  # noqa: E501
        :rtype: str
        """
        return self._threedi_version

    @threedi_version.setter
    def threedi_version(self, threedi_version):
        """Sets the threedi_version of this InpyVersion.


        :param threedi_version: The threedi_version of this InpyVersion.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and threedi_version is None:  # noqa: E501
            raise ValueError("Invalid value for `threedi_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                threedi_version is not None and len(threedi_version) > 80):
            raise ValueError("Invalid value for `threedi_version`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                threedi_version is not None and len(threedi_version) < 1):
            raise ValueError("Invalid value for `threedi_version`, length must be greater than or equal to `1`")  # noqa: E501

        self._threedi_version = threedi_version

    @property
    def threedicore_version(self):
        """Gets the threedicore_version of this InpyVersion.  # noqa: E501


        :return: The threedicore_version of this InpyVersion.  # noqa: E501
        :rtype: str
        """
        return self._threedicore_version

    @threedicore_version.setter
    def threedicore_version(self, threedicore_version):
        """Sets the threedicore_version of this InpyVersion.


        :param threedicore_version: The threedicore_version of this InpyVersion.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and threedicore_version is None:  # noqa: E501
            raise ValueError("Invalid value for `threedicore_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                threedicore_version is not None and len(threedicore_version) > 80):
            raise ValueError("Invalid value for `threedicore_version`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                threedicore_version is not None and len(threedicore_version) < 1):
            raise ValueError("Invalid value for `threedicore_version`, length must be greater than or equal to `1`")  # noqa: E501

        self._threedicore_version = threedicore_version

    @property
    def slug(self):
        """Gets the slug of this InpyVersion.  # noqa: E501


        :return: The slug of this InpyVersion.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """Sets the slug of this InpyVersion.


        :param slug: The slug of this InpyVersion.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                slug is not None and len(slug) < 1):
            raise ValueError("Invalid value for `slug`, length must be greater than or equal to `1`")  # noqa: E501

        self._slug = slug

    @property
    def id(self):
        """Gets the id of this InpyVersion.  # noqa: E501


        :return: The id of this InpyVersion.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InpyVersion.


        :param id: The id of this InpyVersion.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def active(self):
        """Gets the active of this InpyVersion.  # noqa: E501


        :return: The active of this InpyVersion.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this InpyVersion.


        :param active: The active of this InpyVersion.  # noqa: E501
        :type: bool
        """

        self._active = active

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InpyVersion):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InpyVersion):
            return True

        return self.to_dict() != other.to_dict()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages
import codecs
import re
import os

here = os.path.abspath(os.path.dirname(__file__))


with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()


def read(*parts):
    with codecs.open(os.path.join(here, *parts), 'r') as fp:
        return fp.read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")

requirements = [
    'certifi>=2019.3.9',
    'urllib3>=1.15',
    'pyjwt>=1.7.1',
    'six>=1.10',
    'python-dateutil',
]

aio_requirements = ['aiohttp>=3.6.3', "aiofiles"]

# Note: mock contains a backport of AsyncMock
test_requirements = ["pytest", "pytest-asyncio", "mock"]


setup(
    author="Lars Claussen",
    author_email='lars.claussen@nelen-schuurmans.nl',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    description="client for the threedi API",
    install_requires=requirements,
    license="BSD license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='threedi_openapi_client',
    name='threedi_api_client',
    packages=find_packages(
        include=[
            'openapi_client', 'openapi_client.*',
            'threedi_api_client', 'threedi_api_client.*'
        ]
    ),
    python_requires='>=3.6',
    extras_require={
        "aio": aio_requirements,
        "test": test_requirements,
    },
    test_suite='tests',
    url='https://github.com/nens/threedi-openapi-client',
    version=find_version("openapi_client", "__init__.py"),
    zip_safe=False,
)



# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class WaterLevelProfileRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'geometry': 'Linestring',
        'points_limit': 'int',
        'subscribe': 'bool',
        'subscribe_rate_limit': 'float'
    }

    attribute_map = {
        'geometry': 'geometry',
        'points_limit': 'points_limit',
        'subscribe': 'subscribe',
        'subscribe_rate_limit': 'subscribe_rate_limit'
    }

    def __init__(self, geometry=None, points_limit=None, subscribe=None, subscribe_rate_limit=None, local_vars_configuration=None):  # noqa: E501
        """WaterLevelProfileRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._geometry = None
        self._points_limit = None
        self._subscribe = None
        self._subscribe_rate_limit = None
        self.discriminator = None

        self.geometry = geometry
        if points_limit is not None:
            self.points_limit = points_limit
        self.subscribe = subscribe
        if subscribe_rate_limit is not None:
            self.subscribe_rate_limit = subscribe_rate_limit

    @property
    def geometry(self):
        """Gets the geometry of this WaterLevelProfileRequest.  # noqa: E501


        :return: The geometry of this WaterLevelProfileRequest.  # noqa: E501
        :rtype: Linestring
        """
        return self._geometry

    @geometry.setter
    def geometry(self, geometry):
        """Sets the geometry of this WaterLevelProfileRequest.


        :param geometry: The geometry of this WaterLevelProfileRequest.  # noqa: E501
        :type: Linestring
        """
        if self.local_vars_configuration.client_side_validation and geometry is None:  # noqa: E501
            raise ValueError("Invalid value for `geometry`, must not be `None`")  # noqa: E501

        self._geometry = geometry

    @property
    def points_limit(self):
        """Gets the points_limit of this WaterLevelProfileRequest.  # noqa: E501

        Maximum number of points to return  # noqa: E501

        :return: The points_limit of this WaterLevelProfileRequest.  # noqa: E501
        :rtype: int
        """
        return self._points_limit

    @points_limit.setter
    def points_limit(self, points_limit):
        """Sets the points_limit of this WaterLevelProfileRequest.

        Maximum number of points to return  # noqa: E501

        :param points_limit: The points_limit of this WaterLevelProfileRequest.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                points_limit is not None and points_limit > 200):  # noqa: E501
            raise ValueError("Invalid value for `points_limit`, must be a value less than or equal to `200`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                points_limit is not None and points_limit < 1):  # noqa: E501
            raise ValueError("Invalid value for `points_limit`, must be a value greater than or equal to `1`")  # noqa: E501

        self._points_limit = points_limit

    @property
    def subscribe(self):
        """Gets the subscribe of this WaterLevelProfileRequest.  # noqa: E501

        Subscribe for new results during simulation  # noqa: E501

        :return: The subscribe of this WaterLevelProfileRequest.  # noqa: E501
        :rtype: bool
        """
        return self._subscribe

    @subscribe.setter
    def subscribe(self, subscribe):
        """Sets the subscribe of this WaterLevelProfileRequest.

        Subscribe for new results during simulation  # noqa: E501

        :param subscribe: The subscribe of this WaterLevelProfileRequest.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and subscribe is None:  # noqa: E501
            raise ValueError("Invalid value for `subscribe`, must not be `None`")  # noqa: E501

        self._subscribe = subscribe

    @property
    def subscribe_rate_limit(self):
        """Gets the subscribe_rate_limit of this WaterLevelProfileRequest.  # noqa: E501

        Max number of items per second for subscription  # noqa: E501

        :return: The subscribe_rate_limit of this WaterLevelProfileRequest.  # noqa: E501
        :rtype: float
        """
        return self._subscribe_rate_limit

    @subscribe_rate_limit.setter
    def subscribe_rate_limit(self, subscribe_rate_limit):
        """Sets the subscribe_rate_limit of this WaterLevelProfileRequest.

        Max number of items per second for subscription  # noqa: E501

        :param subscribe_rate_limit: The subscribe_rate_limit of this WaterLevelProfileRequest.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                subscribe_rate_limit is not None and subscribe_rate_limit > 1):  # noqa: E501
            raise ValueError("Invalid value for `subscribe_rate_limit`, must be a value less than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                subscribe_rate_limit is not None and subscribe_rate_limit < 0.25):  # noqa: E501
            raise ValueError("Invalid value for `subscribe_rate_limit`, must be a value greater than or equal to `0.25`")  # noqa: E501

        self._subscribe_rate_limit = subscribe_rate_limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WaterLevelProfileRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WaterLevelProfileRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class FileMeta(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'values_reference': 'str',
        'units': 'str',
        'timestamps': 'list[int]',
        'offset': 'int',
        'duration': 'int',
        'geotransform': 'list[float]',
        'epsg_code': 'int',
        'interval': 'int',
        'error': 'str',
        'fill_value': 'str'
    }

    attribute_map = {
        'values_reference': 'values_reference',
        'units': 'units',
        'timestamps': 'timestamps',
        'offset': 'offset',
        'duration': 'duration',
        'geotransform': 'geotransform',
        'epsg_code': 'epsg_code',
        'interval': 'interval',
        'error': 'error',
        'fill_value': 'fill_value'
    }

    def __init__(self, values_reference=None, units=None, timestamps=None, offset=None, duration=None, geotransform=None, epsg_code=None, interval=None, error=None, fill_value=None, local_vars_configuration=None):  # noqa: E501
        """FileMeta - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._values_reference = None
        self._units = None
        self._timestamps = None
        self._offset = None
        self._duration = None
        self._geotransform = None
        self._epsg_code = None
        self._interval = None
        self._error = None
        self._fill_value = None
        self.discriminator = None

        if values_reference is not None:
            self.values_reference = values_reference
        if units is not None:
            self.units = units
        if timestamps is not None:
            self.timestamps = timestamps
        if offset is not None:
            self.offset = offset
        if duration is not None:
            self.duration = duration
        if geotransform is not None:
            self.geotransform = geotransform
        if epsg_code is not None:
            self.epsg_code = epsg_code
        if interval is not None:
            self.interval = interval
        if error is not None:
            self.error = error
        if fill_value is not None:
            self.fill_value = fill_value

    @property
    def values_reference(self):
        """Gets the values_reference of this FileMeta.  # noqa: E501


        :return: The values_reference of this FileMeta.  # noqa: E501
        :rtype: str
        """
        return self._values_reference

    @values_reference.setter
    def values_reference(self, values_reference):
        """Sets the values_reference of this FileMeta.


        :param values_reference: The values_reference of this FileMeta.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                values_reference is not None and len(values_reference) > 255):
            raise ValueError("Invalid value for `values_reference`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                values_reference is not None and len(values_reference) < 1):
            raise ValueError("Invalid value for `values_reference`, length must be greater than or equal to `1`")  # noqa: E501

        self._values_reference = values_reference

    @property
    def units(self):
        """Gets the units of this FileMeta.  # noqa: E501


        :return: The units of this FileMeta.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this FileMeta.


        :param units: The units of this FileMeta.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                units is not None and len(units) > 64):
            raise ValueError("Invalid value for `units`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                units is not None and len(units) < 1):
            raise ValueError("Invalid value for `units`, length must be greater than or equal to `1`")  # noqa: E501

        self._units = units

    @property
    def timestamps(self):
        """Gets the timestamps of this FileMeta.  # noqa: E501

        seconds in the simulation  # noqa: E501

        :return: The timestamps of this FileMeta.  # noqa: E501
        :rtype: list[int]
        """
        return self._timestamps

    @timestamps.setter
    def timestamps(self, timestamps):
        """Sets the timestamps of this FileMeta.

        seconds in the simulation  # noqa: E501

        :param timestamps: The timestamps of this FileMeta.  # noqa: E501
        :type: list[int]
        """

        self._timestamps = timestamps

    @property
    def offset(self):
        """Gets the offset of this FileMeta.  # noqa: E501

        seconds in the simulation  # noqa: E501

        :return: The offset of this FileMeta.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this FileMeta.

        seconds in the simulation  # noqa: E501

        :param offset: The offset of this FileMeta.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                offset is not None and offset < 0):  # noqa: E501
            raise ValueError("Invalid value for `offset`, must be a value greater than or equal to `0`")  # noqa: E501

        self._offset = offset

    @property
    def duration(self):
        """Gets the duration of this FileMeta.  # noqa: E501

        seconds  # noqa: E501

        :return: The duration of this FileMeta.  # noqa: E501
        :rtype: int
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this FileMeta.

        seconds  # noqa: E501

        :param duration: The duration of this FileMeta.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                duration is not None and duration < 0):  # noqa: E501
            raise ValueError("Invalid value for `duration`, must be a value greater than or equal to `0`")  # noqa: E501

        self._duration = duration

    @property
    def geotransform(self):
        """Gets the geotransform of this FileMeta.  # noqa: E501


        :return: The geotransform of this FileMeta.  # noqa: E501
        :rtype: list[float]
        """
        return self._geotransform

    @geotransform.setter
    def geotransform(self, geotransform):
        """Sets the geotransform of this FileMeta.


        :param geotransform: The geotransform of this FileMeta.  # noqa: E501
        :type: list[float]
        """

        self._geotransform = geotransform

    @property
    def epsg_code(self):
        """Gets the epsg_code of this FileMeta.  # noqa: E501


        :return: The epsg_code of this FileMeta.  # noqa: E501
        :rtype: int
        """
        return self._epsg_code

    @epsg_code.setter
    def epsg_code(self, epsg_code):
        """Sets the epsg_code of this FileMeta.


        :param epsg_code: The epsg_code of this FileMeta.  # noqa: E501
        :type: int
        """

        self._epsg_code = epsg_code

    @property
    def interval(self):
        """Gets the interval of this FileMeta.  # noqa: E501


        :return: The interval of this FileMeta.  # noqa: E501
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this FileMeta.


        :param interval: The interval of this FileMeta.  # noqa: E501
        :type: int
        """

        self._interval = interval

    @property
    def error(self):
        """Gets the error of this FileMeta.  # noqa: E501


        :return: The error of this FileMeta.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this FileMeta.


        :param error: The error of this FileMeta.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                error is not None and len(error) > 512):
            raise ValueError("Invalid value for `error`, length must be less than or equal to `512`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                error is not None and len(error) < 1):
            raise ValueError("Invalid value for `error`, length must be greater than or equal to `1`")  # noqa: E501

        self._error = error

    @property
    def fill_value(self):
        """Gets the fill_value of this FileMeta.  # noqa: E501


        :return: The fill_value of this FileMeta.  # noqa: E501
        :rtype: str
        """
        return self._fill_value

    @fill_value.setter
    def fill_value(self, fill_value):
        """Sets the fill_value of this FileMeta.


        :param fill_value: The fill_value of this FileMeta.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                fill_value is not None and len(fill_value) > 128):
            raise ValueError("Invalid value for `fill_value`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                fill_value is not None and len(fill_value) < 1):
            raise ValueError("Invalid value for `fill_value`, length must be greater than or equal to `1`")  # noqa: E501

        self._fill_value = fill_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileMeta):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileMeta):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class TimeStepSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'simulation_id': 'int',
        'time_step': 'float',
        'min_time_step': 'float',
        'max_time_step': 'float',
        'use_time_step_stretch': 'bool',
        'output_time_step': 'float'
    }

    attribute_map = {
        'id': 'id',
        'simulation_id': 'simulation_id',
        'time_step': 'time_step',
        'min_time_step': 'min_time_step',
        'max_time_step': 'max_time_step',
        'use_time_step_stretch': 'use_time_step_stretch',
        'output_time_step': 'output_time_step'
    }

    def __init__(self, id=None, simulation_id=None, time_step=None, min_time_step=None, max_time_step=None, use_time_step_stretch=None, output_time_step=None, local_vars_configuration=None):  # noqa: E501
        """TimeStepSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._simulation_id = None
        self._time_step = None
        self._min_time_step = None
        self._max_time_step = None
        self._use_time_step_stretch = None
        self._output_time_step = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if simulation_id is not None:
            self.simulation_id = simulation_id
        self.time_step = time_step
        self.min_time_step = min_time_step
        self.max_time_step = max_time_step
        self.use_time_step_stretch = use_time_step_stretch
        self.output_time_step = output_time_step

    @property
    def id(self):
        """Gets the id of this TimeStepSettings.  # noqa: E501


        :return: The id of this TimeStepSettings.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TimeStepSettings.


        :param id: The id of this TimeStepSettings.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def simulation_id(self):
        """Gets the simulation_id of this TimeStepSettings.  # noqa: E501


        :return: The simulation_id of this TimeStepSettings.  # noqa: E501
        :rtype: int
        """
        return self._simulation_id

    @simulation_id.setter
    def simulation_id(self, simulation_id):
        """Sets the simulation_id of this TimeStepSettings.


        :param simulation_id: The simulation_id of this TimeStepSettings.  # noqa: E501
        :type: int
        """

        self._simulation_id = simulation_id

    @property
    def time_step(self):
        """Gets the time_step of this TimeStepSettings.  # noqa: E501

        Size of the simulation time step in seconds.  # noqa: E501

        :return: The time_step of this TimeStepSettings.  # noqa: E501
        :rtype: float
        """
        return self._time_step

    @time_step.setter
    def time_step(self, time_step):
        """Sets the time_step of this TimeStepSettings.

        Size of the simulation time step in seconds.  # noqa: E501

        :param time_step: The time_step of this TimeStepSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and time_step is None:  # noqa: E501
            raise ValueError("Invalid value for `time_step`, must not be `None`")  # noqa: E501

        self._time_step = time_step

    @property
    def min_time_step(self):
        """Gets the min_time_step of this TimeStepSettings.  # noqa: E501

        Minimum size of the simulation time step in seconds. Suitable default is 0.001.  # noqa: E501

        :return: The min_time_step of this TimeStepSettings.  # noqa: E501
        :rtype: float
        """
        return self._min_time_step

    @min_time_step.setter
    def min_time_step(self, min_time_step):
        """Sets the min_time_step of this TimeStepSettings.

        Minimum size of the simulation time step in seconds. Suitable default is 0.001.  # noqa: E501

        :param min_time_step: The min_time_step of this TimeStepSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and min_time_step is None:  # noqa: E501
            raise ValueError("Invalid value for `min_time_step`, must not be `None`")  # noqa: E501

        self._min_time_step = min_time_step

    @property
    def max_time_step(self):
        """Gets the max_time_step of this TimeStepSettings.  # noqa: E501

        Only in combination with use_time_step_stretch=True.  # noqa: E501

        :return: The max_time_step of this TimeStepSettings.  # noqa: E501
        :rtype: float
        """
        return self._max_time_step

    @max_time_step.setter
    def max_time_step(self, max_time_step):
        """Sets the max_time_step of this TimeStepSettings.

        Only in combination with use_time_step_stretch=True.  # noqa: E501

        :param max_time_step: The max_time_step of this TimeStepSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and max_time_step is None:  # noqa: E501
            raise ValueError("Invalid value for `max_time_step`, must not be `None`")  # noqa: E501

        self._max_time_step = max_time_step

    @property
    def use_time_step_stretch(self):
        """Gets the use_time_step_stretch of this TimeStepSettings.  # noqa: E501

        Permit the time step to increase automatically, when the flow allows it.  # noqa: E501

        :return: The use_time_step_stretch of this TimeStepSettings.  # noqa: E501
        :rtype: bool
        """
        return self._use_time_step_stretch

    @use_time_step_stretch.setter
    def use_time_step_stretch(self, use_time_step_stretch):
        """Sets the use_time_step_stretch of this TimeStepSettings.

        Permit the time step to increase automatically, when the flow allows it.  # noqa: E501

        :param use_time_step_stretch: The use_time_step_stretch of this TimeStepSettings.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and use_time_step_stretch is None:  # noqa: E501
            raise ValueError("Invalid value for `use_time_step_stretch`, must not be `None`")  # noqa: E501

        self._use_time_step_stretch = use_time_step_stretch

    @property
    def output_time_step(self):
        """Gets the output_time_step of this TimeStepSettings.  # noqa: E501

        The interval in seconds in which results are saved to disk.  # noqa: E501

        :return: The output_time_step of this TimeStepSettings.  # noqa: E501
        :rtype: float
        """
        return self._output_time_step

    @output_time_step.setter
    def output_time_step(self, output_time_step):
        """Sets the output_time_step of this TimeStepSettings.

        The interval in seconds in which results are saved to disk.  # noqa: E501

        :param output_time_step: The output_time_step of this TimeStepSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and output_time_step is None:  # noqa: E501
            raise ValueError("Invalid value for `output_time_step`, must not be `None`")  # noqa: E501

        self._output_time_step = output_time_step

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimeStepSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TimeStepSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class Breach(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'url': 'str',
        'potential_breach': 'str',
        'line_id': 'int',
        'duration_till_max_depth': 'int',
        'maximum_breach_depth': 'float',
        'levee_material': 'str',
        'initial_width': 'float',
        'discharge_coefficient_positive': 'float',
        'discharge_coefficient_negative': 'float',
        'simulation': 'str',
        'offset': 'int',
        'id': 'int',
        'uid': 'str'
    }

    attribute_map = {
        'url': 'url',
        'potential_breach': 'potential_breach',
        'line_id': 'line_id',
        'duration_till_max_depth': 'duration_till_max_depth',
        'maximum_breach_depth': 'maximum_breach_depth',
        'levee_material': 'levee_material',
        'initial_width': 'initial_width',
        'discharge_coefficient_positive': 'discharge_coefficient_positive',
        'discharge_coefficient_negative': 'discharge_coefficient_negative',
        'simulation': 'simulation',
        'offset': 'offset',
        'id': 'id',
        'uid': 'uid'
    }

    def __init__(self, url=None, potential_breach=None, line_id=None, duration_till_max_depth=None, maximum_breach_depth=None, levee_material=None, initial_width=None, discharge_coefficient_positive=None, discharge_coefficient_negative=None, simulation=None, offset=None, id=None, uid=None, local_vars_configuration=None):  # noqa: E501
        """Breach - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._url = None
        self._potential_breach = None
        self._line_id = None
        self._duration_till_max_depth = None
        self._maximum_breach_depth = None
        self._levee_material = None
        self._initial_width = None
        self._discharge_coefficient_positive = None
        self._discharge_coefficient_negative = None
        self._simulation = None
        self._offset = None
        self._id = None
        self._uid = None
        self.discriminator = None

        if url is not None:
            self.url = url
        self.potential_breach = potential_breach
        if line_id is not None:
            self.line_id = line_id
        self.duration_till_max_depth = duration_till_max_depth
        self.maximum_breach_depth = maximum_breach_depth
        self.levee_material = levee_material
        self.initial_width = initial_width
        self.discharge_coefficient_positive = discharge_coefficient_positive
        self.discharge_coefficient_negative = discharge_coefficient_negative
        if simulation is not None:
            self.simulation = simulation
        self.offset = offset
        if id is not None:
            self.id = id
        if uid is not None:
            self.uid = uid

    @property
    def url(self):
        """Gets the url of this Breach.  # noqa: E501


        :return: The url of this Breach.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Breach.


        :param url: The url of this Breach.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def potential_breach(self):
        """Gets the potential_breach of this Breach.  # noqa: E501


        :return: The potential_breach of this Breach.  # noqa: E501
        :rtype: str
        """
        return self._potential_breach

    @potential_breach.setter
    def potential_breach(self, potential_breach):
        """Sets the potential_breach of this Breach.


        :param potential_breach: The potential_breach of this Breach.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and potential_breach is None:  # noqa: E501
            raise ValueError("Invalid value for `potential_breach`, must not be `None`")  # noqa: E501

        self._potential_breach = potential_breach

    @property
    def line_id(self):
        """Gets the line_id of this Breach.  # noqa: E501


        :return: The line_id of this Breach.  # noqa: E501
        :rtype: int
        """
        return self._line_id

    @line_id.setter
    def line_id(self, line_id):
        """Sets the line_id of this Breach.


        :param line_id: The line_id of this Breach.  # noqa: E501
        :type: int
        """

        self._line_id = line_id

    @property
    def duration_till_max_depth(self):
        """Gets the duration_till_max_depth of this Breach.  # noqa: E501

        duration till maximum depth in seconds  # noqa: E501

        :return: The duration_till_max_depth of this Breach.  # noqa: E501
        :rtype: int
        """
        return self._duration_till_max_depth

    @duration_till_max_depth.setter
    def duration_till_max_depth(self, duration_till_max_depth):
        """Sets the duration_till_max_depth of this Breach.

        duration till maximum depth in seconds  # noqa: E501

        :param duration_till_max_depth: The duration_till_max_depth of this Breach.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and duration_till_max_depth is None:  # noqa: E501
            raise ValueError("Invalid value for `duration_till_max_depth`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                duration_till_max_depth is not None and duration_till_max_depth > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `duration_till_max_depth`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                duration_till_max_depth is not None and duration_till_max_depth < 0):  # noqa: E501
            raise ValueError("Invalid value for `duration_till_max_depth`, must be a value greater than or equal to `0`")  # noqa: E501

        self._duration_till_max_depth = duration_till_max_depth

    @property
    def maximum_breach_depth(self):
        """Gets the maximum_breach_depth of this Breach.  # noqa: E501

        Override the maximum_breach_depth of the potential breach  # noqa: E501

        :return: The maximum_breach_depth of this Breach.  # noqa: E501
        :rtype: float
        """
        return self._maximum_breach_depth

    @maximum_breach_depth.setter
    def maximum_breach_depth(self, maximum_breach_depth):
        """Sets the maximum_breach_depth of this Breach.

        Override the maximum_breach_depth of the potential breach  # noqa: E501

        :param maximum_breach_depth: The maximum_breach_depth of this Breach.  # noqa: E501
        :type: float
        """

        self._maximum_breach_depth = maximum_breach_depth

    @property
    def levee_material(self):
        """Gets the levee_material of this Breach.  # noqa: E501

        Override the levee_material of the potential breach  # noqa: E501

        :return: The levee_material of this Breach.  # noqa: E501
        :rtype: str
        """
        return self._levee_material

    @levee_material.setter
    def levee_material(self, levee_material):
        """Sets the levee_material of this Breach.

        Override the levee_material of the potential breach  # noqa: E501

        :param levee_material: The levee_material of this Breach.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"sand", "clay"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and levee_material not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `levee_material` ({0}), must be one of {1}"  # noqa: E501
                .format(levee_material, allowed_values)
            )

        self._levee_material = levee_material

    @property
    def initial_width(self):
        """Gets the initial_width of this Breach.  # noqa: E501

        initial width in meters  # noqa: E501

        :return: The initial_width of this Breach.  # noqa: E501
        :rtype: float
        """
        return self._initial_width

    @initial_width.setter
    def initial_width(self, initial_width):
        """Sets the initial_width of this Breach.

        initial width in meters  # noqa: E501

        :param initial_width: The initial_width of this Breach.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and initial_width is None:  # noqa: E501
            raise ValueError("Invalid value for `initial_width`, must not be `None`")  # noqa: E501

        self._initial_width = initial_width

    @property
    def discharge_coefficient_positive(self):
        """Gets the discharge_coefficient_positive of this Breach.  # noqa: E501


        :return: The discharge_coefficient_positive of this Breach.  # noqa: E501
        :rtype: float
        """
        return self._discharge_coefficient_positive

    @discharge_coefficient_positive.setter
    def discharge_coefficient_positive(self, discharge_coefficient_positive):
        """Sets the discharge_coefficient_positive of this Breach.


        :param discharge_coefficient_positive: The discharge_coefficient_positive of this Breach.  # noqa: E501
        :type: float
        """

        self._discharge_coefficient_positive = discharge_coefficient_positive

    @property
    def discharge_coefficient_negative(self):
        """Gets the discharge_coefficient_negative of this Breach.  # noqa: E501


        :return: The discharge_coefficient_negative of this Breach.  # noqa: E501
        :rtype: float
        """
        return self._discharge_coefficient_negative

    @discharge_coefficient_negative.setter
    def discharge_coefficient_negative(self, discharge_coefficient_negative):
        """Sets the discharge_coefficient_negative of this Breach.


        :param discharge_coefficient_negative: The discharge_coefficient_negative of this Breach.  # noqa: E501
        :type: float
        """

        self._discharge_coefficient_negative = discharge_coefficient_negative

    @property
    def simulation(self):
        """Gets the simulation of this Breach.  # noqa: E501


        :return: The simulation of this Breach.  # noqa: E501
        :rtype: str
        """
        return self._simulation

    @simulation.setter
    def simulation(self, simulation):
        """Sets the simulation of this Breach.


        :param simulation: The simulation of this Breach.  # noqa: E501
        :type: str
        """

        self._simulation = simulation

    @property
    def offset(self):
        """Gets the offset of this Breach.  # noqa: E501

        offset of event in simulation in seconds  # noqa: E501

        :return: The offset of this Breach.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this Breach.

        offset of event in simulation in seconds  # noqa: E501

        :param offset: The offset of this Breach.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and offset is None:  # noqa: E501
            raise ValueError("Invalid value for `offset`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                offset is not None and offset > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `offset`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                offset is not None and offset < 0):  # noqa: E501
            raise ValueError("Invalid value for `offset`, must be a value greater than or equal to `0`")  # noqa: E501

        self._offset = offset

    @property
    def id(self):
        """Gets the id of this Breach.  # noqa: E501


        :return: The id of this Breach.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Breach.


        :param id: The id of this Breach.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def uid(self):
        """Gets the uid of this Breach.  # noqa: E501


        :return: The uid of this Breach.  # noqa: E501
        :rtype: str
        """
        return self._uid

    @uid.setter
    def uid(self, uid):
        """Sets the uid of this Breach.


        :param uid: The uid of this Breach.  # noqa: E501
        :type: str
        """

        self._uid = uid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Breach):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Breach):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class RasterOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'dem_file': 'str',
        'dem_raw_file': 'str',
        'equilibrium_infiltration_rate_file': 'str',
        'frict_coef_file': 'str',
        'initial_groundwater_level_file': 'str',
        'initial_waterlevel_file': 'str',
        'groundwater_hydro_connectivity_file': 'str',
        'groundwater_impervious_layer_level_file': 'str',
        'infiltration_decay_period_file': 'str',
        'initial_infiltration_rate_file': 'str',
        'leakage_file': 'str',
        'phreatic_storage_capacity_file': 'str',
        'hydraulic_conductivity_file': 'str',
        'porosity_file': 'str',
        'infiltration_rate_file': 'str',
        'max_infiltration_capacity_file': 'str',
        'interception_file': 'str'
    }

    attribute_map = {
        'dem_file': 'dem_file',
        'dem_raw_file': 'dem_raw_file',
        'equilibrium_infiltration_rate_file': 'equilibrium_infiltration_rate_file',
        'frict_coef_file': 'frict_coef_file',
        'initial_groundwater_level_file': 'initial_groundwater_level_file',
        'initial_waterlevel_file': 'initial_waterlevel_file',
        'groundwater_hydro_connectivity_file': 'groundwater_hydro_connectivity_file',
        'groundwater_impervious_layer_level_file': 'groundwater_impervious_layer_level_file',
        'infiltration_decay_period_file': 'infiltration_decay_period_file',
        'initial_infiltration_rate_file': 'initial_infiltration_rate_file',
        'leakage_file': 'leakage_file',
        'phreatic_storage_capacity_file': 'phreatic_storage_capacity_file',
        'hydraulic_conductivity_file': 'hydraulic_conductivity_file',
        'porosity_file': 'porosity_file',
        'infiltration_rate_file': 'infiltration_rate_file',
        'max_infiltration_capacity_file': 'max_infiltration_capacity_file',
        'interception_file': 'interception_file'
    }

    def __init__(self, dem_file=None, dem_raw_file=None, equilibrium_infiltration_rate_file=None, frict_coef_file=None, initial_groundwater_level_file=None, initial_waterlevel_file=None, groundwater_hydro_connectivity_file=None, groundwater_impervious_layer_level_file=None, infiltration_decay_period_file=None, initial_infiltration_rate_file=None, leakage_file=None, phreatic_storage_capacity_file=None, hydraulic_conductivity_file=None, porosity_file=None, infiltration_rate_file=None, max_infiltration_capacity_file=None, interception_file=None, local_vars_configuration=None):  # noqa: E501
        """RasterOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._dem_file = None
        self._dem_raw_file = None
        self._equilibrium_infiltration_rate_file = None
        self._frict_coef_file = None
        self._initial_groundwater_level_file = None
        self._initial_waterlevel_file = None
        self._groundwater_hydro_connectivity_file = None
        self._groundwater_impervious_layer_level_file = None
        self._infiltration_decay_period_file = None
        self._initial_infiltration_rate_file = None
        self._leakage_file = None
        self._phreatic_storage_capacity_file = None
        self._hydraulic_conductivity_file = None
        self._porosity_file = None
        self._infiltration_rate_file = None
        self._max_infiltration_capacity_file = None
        self._interception_file = None
        self.discriminator = None

        if dem_file is not None:
            self.dem_file = dem_file
        if dem_raw_file is not None:
            self.dem_raw_file = dem_raw_file
        if equilibrium_infiltration_rate_file is not None:
            self.equilibrium_infiltration_rate_file = equilibrium_infiltration_rate_file
        if frict_coef_file is not None:
            self.frict_coef_file = frict_coef_file
        if initial_groundwater_level_file is not None:
            self.initial_groundwater_level_file = initial_groundwater_level_file
        if initial_waterlevel_file is not None:
            self.initial_waterlevel_file = initial_waterlevel_file
        if groundwater_hydro_connectivity_file is not None:
            self.groundwater_hydro_connectivity_file = groundwater_hydro_connectivity_file
        if groundwater_impervious_layer_level_file is not None:
            self.groundwater_impervious_layer_level_file = groundwater_impervious_layer_level_file
        if infiltration_decay_period_file is not None:
            self.infiltration_decay_period_file = infiltration_decay_period_file
        if initial_infiltration_rate_file is not None:
            self.initial_infiltration_rate_file = initial_infiltration_rate_file
        if leakage_file is not None:
            self.leakage_file = leakage_file
        if phreatic_storage_capacity_file is not None:
            self.phreatic_storage_capacity_file = phreatic_storage_capacity_file
        if hydraulic_conductivity_file is not None:
            self.hydraulic_conductivity_file = hydraulic_conductivity_file
        if porosity_file is not None:
            self.porosity_file = porosity_file
        if infiltration_rate_file is not None:
            self.infiltration_rate_file = infiltration_rate_file
        if max_infiltration_capacity_file is not None:
            self.max_infiltration_capacity_file = max_infiltration_capacity_file
        if interception_file is not None:
            self.interception_file = interception_file

    @property
    def dem_file(self):
        """Gets the dem_file of this RasterOptions.  # noqa: E501


        :return: The dem_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._dem_file

    @dem_file.setter
    def dem_file(self, dem_file):
        """Sets the dem_file of this RasterOptions.


        :param dem_file: The dem_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                dem_file is not None and len(dem_file) > 80):
            raise ValueError("Invalid value for `dem_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                dem_file is not None and len(dem_file) < 1):
            raise ValueError("Invalid value for `dem_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._dem_file = dem_file

    @property
    def dem_raw_file(self):
        """Gets the dem_raw_file of this RasterOptions.  # noqa: E501


        :return: The dem_raw_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._dem_raw_file

    @dem_raw_file.setter
    def dem_raw_file(self, dem_raw_file):
        """Sets the dem_raw_file of this RasterOptions.


        :param dem_raw_file: The dem_raw_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                dem_raw_file is not None and len(dem_raw_file) > 80):
            raise ValueError("Invalid value for `dem_raw_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                dem_raw_file is not None and len(dem_raw_file) < 1):
            raise ValueError("Invalid value for `dem_raw_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._dem_raw_file = dem_raw_file

    @property
    def equilibrium_infiltration_rate_file(self):
        """Gets the equilibrium_infiltration_rate_file of this RasterOptions.  # noqa: E501


        :return: The equilibrium_infiltration_rate_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._equilibrium_infiltration_rate_file

    @equilibrium_infiltration_rate_file.setter
    def equilibrium_infiltration_rate_file(self, equilibrium_infiltration_rate_file):
        """Sets the equilibrium_infiltration_rate_file of this RasterOptions.


        :param equilibrium_infiltration_rate_file: The equilibrium_infiltration_rate_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                equilibrium_infiltration_rate_file is not None and len(equilibrium_infiltration_rate_file) > 80):
            raise ValueError("Invalid value for `equilibrium_infiltration_rate_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                equilibrium_infiltration_rate_file is not None and len(equilibrium_infiltration_rate_file) < 1):
            raise ValueError("Invalid value for `equilibrium_infiltration_rate_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._equilibrium_infiltration_rate_file = equilibrium_infiltration_rate_file

    @property
    def frict_coef_file(self):
        """Gets the frict_coef_file of this RasterOptions.  # noqa: E501


        :return: The frict_coef_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._frict_coef_file

    @frict_coef_file.setter
    def frict_coef_file(self, frict_coef_file):
        """Sets the frict_coef_file of this RasterOptions.


        :param frict_coef_file: The frict_coef_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                frict_coef_file is not None and len(frict_coef_file) > 80):
            raise ValueError("Invalid value for `frict_coef_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                frict_coef_file is not None and len(frict_coef_file) < 1):
            raise ValueError("Invalid value for `frict_coef_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._frict_coef_file = frict_coef_file

    @property
    def initial_groundwater_level_file(self):
        """Gets the initial_groundwater_level_file of this RasterOptions.  # noqa: E501


        :return: The initial_groundwater_level_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._initial_groundwater_level_file

    @initial_groundwater_level_file.setter
    def initial_groundwater_level_file(self, initial_groundwater_level_file):
        """Sets the initial_groundwater_level_file of this RasterOptions.


        :param initial_groundwater_level_file: The initial_groundwater_level_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                initial_groundwater_level_file is not None and len(initial_groundwater_level_file) > 80):
            raise ValueError("Invalid value for `initial_groundwater_level_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                initial_groundwater_level_file is not None and len(initial_groundwater_level_file) < 1):
            raise ValueError("Invalid value for `initial_groundwater_level_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._initial_groundwater_level_file = initial_groundwater_level_file

    @property
    def initial_waterlevel_file(self):
        """Gets the initial_waterlevel_file of this RasterOptions.  # noqa: E501


        :return: The initial_waterlevel_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._initial_waterlevel_file

    @initial_waterlevel_file.setter
    def initial_waterlevel_file(self, initial_waterlevel_file):
        """Sets the initial_waterlevel_file of this RasterOptions.


        :param initial_waterlevel_file: The initial_waterlevel_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                initial_waterlevel_file is not None and len(initial_waterlevel_file) > 80):
            raise ValueError("Invalid value for `initial_waterlevel_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                initial_waterlevel_file is not None and len(initial_waterlevel_file) < 1):
            raise ValueError("Invalid value for `initial_waterlevel_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._initial_waterlevel_file = initial_waterlevel_file

    @property
    def groundwater_hydro_connectivity_file(self):
        """Gets the groundwater_hydro_connectivity_file of this RasterOptions.  # noqa: E501


        :return: The groundwater_hydro_connectivity_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._groundwater_hydro_connectivity_file

    @groundwater_hydro_connectivity_file.setter
    def groundwater_hydro_connectivity_file(self, groundwater_hydro_connectivity_file):
        """Sets the groundwater_hydro_connectivity_file of this RasterOptions.


        :param groundwater_hydro_connectivity_file: The groundwater_hydro_connectivity_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                groundwater_hydro_connectivity_file is not None and len(groundwater_hydro_connectivity_file) > 80):
            raise ValueError("Invalid value for `groundwater_hydro_connectivity_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                groundwater_hydro_connectivity_file is not None and len(groundwater_hydro_connectivity_file) < 1):
            raise ValueError("Invalid value for `groundwater_hydro_connectivity_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._groundwater_hydro_connectivity_file = groundwater_hydro_connectivity_file

    @property
    def groundwater_impervious_layer_level_file(self):
        """Gets the groundwater_impervious_layer_level_file of this RasterOptions.  # noqa: E501


        :return: The groundwater_impervious_layer_level_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._groundwater_impervious_layer_level_file

    @groundwater_impervious_layer_level_file.setter
    def groundwater_impervious_layer_level_file(self, groundwater_impervious_layer_level_file):
        """Sets the groundwater_impervious_layer_level_file of this RasterOptions.


        :param groundwater_impervious_layer_level_file: The groundwater_impervious_layer_level_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                groundwater_impervious_layer_level_file is not None and len(groundwater_impervious_layer_level_file) > 80):
            raise ValueError("Invalid value for `groundwater_impervious_layer_level_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                groundwater_impervious_layer_level_file is not None and len(groundwater_impervious_layer_level_file) < 1):
            raise ValueError("Invalid value for `groundwater_impervious_layer_level_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._groundwater_impervious_layer_level_file = groundwater_impervious_layer_level_file

    @property
    def infiltration_decay_period_file(self):
        """Gets the infiltration_decay_period_file of this RasterOptions.  # noqa: E501


        :return: The infiltration_decay_period_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._infiltration_decay_period_file

    @infiltration_decay_period_file.setter
    def infiltration_decay_period_file(self, infiltration_decay_period_file):
        """Sets the infiltration_decay_period_file of this RasterOptions.


        :param infiltration_decay_period_file: The infiltration_decay_period_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                infiltration_decay_period_file is not None and len(infiltration_decay_period_file) > 80):
            raise ValueError("Invalid value for `infiltration_decay_period_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                infiltration_decay_period_file is not None and len(infiltration_decay_period_file) < 1):
            raise ValueError("Invalid value for `infiltration_decay_period_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._infiltration_decay_period_file = infiltration_decay_period_file

    @property
    def initial_infiltration_rate_file(self):
        """Gets the initial_infiltration_rate_file of this RasterOptions.  # noqa: E501


        :return: The initial_infiltration_rate_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._initial_infiltration_rate_file

    @initial_infiltration_rate_file.setter
    def initial_infiltration_rate_file(self, initial_infiltration_rate_file):
        """Sets the initial_infiltration_rate_file of this RasterOptions.


        :param initial_infiltration_rate_file: The initial_infiltration_rate_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                initial_infiltration_rate_file is not None and len(initial_infiltration_rate_file) > 80):
            raise ValueError("Invalid value for `initial_infiltration_rate_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                initial_infiltration_rate_file is not None and len(initial_infiltration_rate_file) < 1):
            raise ValueError("Invalid value for `initial_infiltration_rate_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._initial_infiltration_rate_file = initial_infiltration_rate_file

    @property
    def leakage_file(self):
        """Gets the leakage_file of this RasterOptions.  # noqa: E501


        :return: The leakage_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._leakage_file

    @leakage_file.setter
    def leakage_file(self, leakage_file):
        """Sets the leakage_file of this RasterOptions.


        :param leakage_file: The leakage_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                leakage_file is not None and len(leakage_file) > 80):
            raise ValueError("Invalid value for `leakage_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                leakage_file is not None and len(leakage_file) < 1):
            raise ValueError("Invalid value for `leakage_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._leakage_file = leakage_file

    @property
    def phreatic_storage_capacity_file(self):
        """Gets the phreatic_storage_capacity_file of this RasterOptions.  # noqa: E501


        :return: The phreatic_storage_capacity_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._phreatic_storage_capacity_file

    @phreatic_storage_capacity_file.setter
    def phreatic_storage_capacity_file(self, phreatic_storage_capacity_file):
        """Sets the phreatic_storage_capacity_file of this RasterOptions.


        :param phreatic_storage_capacity_file: The phreatic_storage_capacity_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                phreatic_storage_capacity_file is not None and len(phreatic_storage_capacity_file) > 80):
            raise ValueError("Invalid value for `phreatic_storage_capacity_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                phreatic_storage_capacity_file is not None and len(phreatic_storage_capacity_file) < 1):
            raise ValueError("Invalid value for `phreatic_storage_capacity_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._phreatic_storage_capacity_file = phreatic_storage_capacity_file

    @property
    def hydraulic_conductivity_file(self):
        """Gets the hydraulic_conductivity_file of this RasterOptions.  # noqa: E501


        :return: The hydraulic_conductivity_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._hydraulic_conductivity_file

    @hydraulic_conductivity_file.setter
    def hydraulic_conductivity_file(self, hydraulic_conductivity_file):
        """Sets the hydraulic_conductivity_file of this RasterOptions.


        :param hydraulic_conductivity_file: The hydraulic_conductivity_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                hydraulic_conductivity_file is not None and len(hydraulic_conductivity_file) > 80):
            raise ValueError("Invalid value for `hydraulic_conductivity_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                hydraulic_conductivity_file is not None and len(hydraulic_conductivity_file) < 1):
            raise ValueError("Invalid value for `hydraulic_conductivity_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._hydraulic_conductivity_file = hydraulic_conductivity_file

    @property
    def porosity_file(self):
        """Gets the porosity_file of this RasterOptions.  # noqa: E501


        :return: The porosity_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._porosity_file

    @porosity_file.setter
    def porosity_file(self, porosity_file):
        """Sets the porosity_file of this RasterOptions.


        :param porosity_file: The porosity_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                porosity_file is not None and len(porosity_file) > 80):
            raise ValueError("Invalid value for `porosity_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                porosity_file is not None and len(porosity_file) < 1):
            raise ValueError("Invalid value for `porosity_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._porosity_file = porosity_file

    @property
    def infiltration_rate_file(self):
        """Gets the infiltration_rate_file of this RasterOptions.  # noqa: E501


        :return: The infiltration_rate_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._infiltration_rate_file

    @infiltration_rate_file.setter
    def infiltration_rate_file(self, infiltration_rate_file):
        """Sets the infiltration_rate_file of this RasterOptions.


        :param infiltration_rate_file: The infiltration_rate_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                infiltration_rate_file is not None and len(infiltration_rate_file) > 80):
            raise ValueError("Invalid value for `infiltration_rate_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                infiltration_rate_file is not None and len(infiltration_rate_file) < 1):
            raise ValueError("Invalid value for `infiltration_rate_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._infiltration_rate_file = infiltration_rate_file

    @property
    def max_infiltration_capacity_file(self):
        """Gets the max_infiltration_capacity_file of this RasterOptions.  # noqa: E501


        :return: The max_infiltration_capacity_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._max_infiltration_capacity_file

    @max_infiltration_capacity_file.setter
    def max_infiltration_capacity_file(self, max_infiltration_capacity_file):
        """Sets the max_infiltration_capacity_file of this RasterOptions.


        :param max_infiltration_capacity_file: The max_infiltration_capacity_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                max_infiltration_capacity_file is not None and len(max_infiltration_capacity_file) > 80):
            raise ValueError("Invalid value for `max_infiltration_capacity_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_infiltration_capacity_file is not None and len(max_infiltration_capacity_file) < 1):
            raise ValueError("Invalid value for `max_infiltration_capacity_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._max_infiltration_capacity_file = max_infiltration_capacity_file

    @property
    def interception_file(self):
        """Gets the interception_file of this RasterOptions.  # noqa: E501


        :return: The interception_file of this RasterOptions.  # noqa: E501
        :rtype: str
        """
        return self._interception_file

    @interception_file.setter
    def interception_file(self, interception_file):
        """Sets the interception_file of this RasterOptions.


        :param interception_file: The interception_file of this RasterOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                interception_file is not None and len(interception_file) > 80):
            raise ValueError("Invalid value for `interception_file`, length must be less than or equal to `80`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                interception_file is not None and len(interception_file) < 1):
            raise ValueError("Invalid value for `interception_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._interception_file = interception_file

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RasterOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RasterOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class Revision(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'url': 'str',
        'id': 'int',
        'repository': 'str',
        'number': 'int',
        'hash': 'str',
        'commit_date': 'datetime',
        'user': 'str',
        'is_pinned': 'bool'
    }

    attribute_map = {
        'url': 'url',
        'id': 'id',
        'repository': 'repository',
        'number': 'number',
        'hash': 'hash',
        'commit_date': 'commit_date',
        'user': 'user',
        'is_pinned': 'is_pinned'
    }

    def __init__(self, url=None, id=None, repository=None, number=None, hash=None, commit_date=None, user=None, is_pinned=None, local_vars_configuration=None):  # noqa: E501
        """Revision - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._url = None
        self._id = None
        self._repository = None
        self._number = None
        self._hash = None
        self._commit_date = None
        self._user = None
        self._is_pinned = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if id is not None:
            self.id = id
        self.repository = repository
        if number is not None:
            self.number = number
        if hash is not None:
            self.hash = hash
        if commit_date is not None:
            self.commit_date = commit_date
        if user is not None:
            self.user = user
        if is_pinned is not None:
            self.is_pinned = is_pinned

    @property
    def url(self):
        """Gets the url of this Revision.  # noqa: E501


        :return: The url of this Revision.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Revision.


        :param url: The url of this Revision.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def id(self):
        """Gets the id of this Revision.  # noqa: E501


        :return: The id of this Revision.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Revision.


        :param id: The id of this Revision.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def repository(self):
        """Gets the repository of this Revision.  # noqa: E501


        :return: The repository of this Revision.  # noqa: E501
        :rtype: str
        """
        return self._repository

    @repository.setter
    def repository(self, repository):
        """Sets the repository of this Revision.


        :param repository: The repository of this Revision.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and repository is None:  # noqa: E501
            raise ValueError("Invalid value for `repository`, must not be `None`")  # noqa: E501

        self._repository = repository

    @property
    def number(self):
        """Gets the number of this Revision.  # noqa: E501


        :return: The number of this Revision.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this Revision.


        :param number: The number of this Revision.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                number is not None and number > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `number`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                number is not None and number < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `number`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._number = number

    @property
    def hash(self):
        """Gets the hash of this Revision.  # noqa: E501

        unique identifier for changeset  # noqa: E501

        :return: The hash of this Revision.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this Revision.

        unique identifier for changeset  # noqa: E501

        :param hash: The hash of this Revision.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                hash is not None and len(hash) > 200):
            raise ValueError("Invalid value for `hash`, length must be less than or equal to `200`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                hash is not None and len(hash) < 1):
            raise ValueError("Invalid value for `hash`, length must be greater than or equal to `1`")  # noqa: E501

        self._hash = hash

    @property
    def commit_date(self):
        """Gets the commit_date of this Revision.  # noqa: E501


        :return: The commit_date of this Revision.  # noqa: E501
        :rtype: datetime
        """
        return self._commit_date

    @commit_date.setter
    def commit_date(self, commit_date):
        """Sets the commit_date of this Revision.


        :param commit_date: The commit_date of this Revision.  # noqa: E501
        :type: datetime
        """

        self._commit_date = commit_date

    @property
    def user(self):
        """Gets the user of this Revision.  # noqa: E501

        user that committed the changeset for this revision  # noqa: E501

        :return: The user of this Revision.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Revision.

        user that committed the changeset for this revision  # noqa: E501

        :param user: The user of this Revision.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                user is not None and len(user) > 128):
            raise ValueError("Invalid value for `user`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                user is not None and len(user) < 1):
            raise ValueError("Invalid value for `user`, length must be greater than or equal to `1`")  # noqa: E501

        self._user = user

    @property
    def is_pinned(self):
        """Gets the is_pinned of this Revision.  # noqa: E501


        :return: The is_pinned of this Revision.  # noqa: E501
        :rtype: bool
        """
        return self._is_pinned

    @is_pinned.setter
    def is_pinned(self, is_pinned):
        """Sets the is_pinned of this Revision.


        :param is_pinned: The is_pinned of this Revision.  # noqa: E501
        :type: bool
        """

        self._is_pinned = is_pinned

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Revision):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Revision):
            return True

        return self.to_dict() != other.to_dict()



import base64
import hashlib
import logging
import os
import re
from pathlib import Path
from typing import BinaryIO, Optional, Tuple
from urllib.parse import urlparse

import urllib3

from openapi_client.exceptions import ApiException

CONTENT_RANGE_REGEXP = re.compile(r"^bytes (\d+)-(\d+)/(\d+|\*)$")


logger = logging.getLogger(__name__)


def get_pool(retries: int = 3, backoff_factor: float = 1.0) -> urllib3.PoolManager:
    """Create a PoolManager with a retry policy.

    The default retry policy has 3 retries with 1, 2, 4 second intervals.

    Args:
        retries: Total number of retries per request
        backoff_factor: Multiplier for retry delay times (1, 2, 4, ...)
    """
    return urllib3.PoolManager(
        retries=urllib3.util.retry.Retry(retries, backoff_factor=backoff_factor)
    )


def download_file(
    url: str,
    target: Path,
    chunk_size: int = 16777216,
    timeout: float = 5.0,
    pool: Optional[urllib3.PoolManager] = None,
) -> Tuple[Path, int]:
    """Download a file to a specified path on disk.

    It is assumed that the file server supports multipart downloads (range
    requests).

    Args:
        url: The url to retrieve.
        target: The location to copy to. If this is an existing file, it is
            overwritten. If it is a directory, a filename is generated from
            the filename in the url.
        chunk_size: The number of bytes per request. Default: 16MB.
        timeout: The total timeout in seconds.
        pool: If not supplied, a default connection pool will be
            created with a retry policy of 3 retries after 1, 2, 4 seconds.

    Returns:
        Tuple of file path, total number of uploaded bytes.

    Raises:
        openapi_client.exceptions.ApiException: raised on unexpected server
            responses (HTTP status codes other than 206, 413, 429, 503)
        urllib3.exceptions.HTTPError: various low-level HTTP errors that persist
            after retrying: connection errors, timeouts, decode errors,
            invalid HTTP headers, payload too large (HTTP 413), too many
            requests (HTTP 429), service unavailable (HTTP 503)
    """
    # cast string to Path if necessary
    if isinstance(target, str):
        target = Path(target)

    # if it is a directory, take the filename from the url
    if target.is_dir():
        target = target / urlparse(url)[2].rsplit("/", 1)[-1]

    # open the file
    try:
        with target.open("wb") as fileobj:
            size = download_fileobj(
                url, fileobj, chunk_size=chunk_size, timeout=timeout, pool=pool
            )
    except Exception:
        # Clean up a partially downloaded file
        try:
            os.remove(target)
        except FileNotFoundError:
            pass
        raise

    return target, size


def download_fileobj(
    url: str,
    fileobj: BinaryIO,
    chunk_size: int = 16777216,
    timeout: float = 5.0,
    pool: Optional[urllib3.PoolManager] = None,
) -> int:
    """Download a url to a file object using multiple requests.

    It is assumed that the file server supports multipart downloads (range
    requests).

    Args:
        url: The url to retrieve.
        fileobj: The (binary) file object to write into.
        chunk_size: The number of bytes per request. Default: 16MB.
        timeout: The total timeout in seconds.
        pool: If not supplied, a default connection pool will be
            created with a retry policy of 3 retries after 1, 2, 4 seconds.

    Returns:
        The total number of downloaded bytes.

    Raises:
        openapi_client.exceptions.ApiException: raised on unexpected server
            responses (HTTP status codes other than 206, 413, 429, 503)
        urllib3.exceptions.HTTPError: various low-level HTTP errors that persist
            after retrying: connection errors, timeouts, decode errors,
            invalid HTTP headers, payload too large (HTTP 413), too many
            requests (HTTP 429), service unavailable (HTTP 503)

        Note that the fileobj might be partially filled with data in case of
        an exception.
    """
    if pool is None:
        pool = get_pool()

    # Our strategy here is to just start downloading chunks while monitoring
    # the Content-Range header to check if we're done. Although we could get
    # the total Content-Length from a HEAD request, not all servers support
    # that (e.g. Minio).
    start = 0
    while True:
        # download a chunk
        stop = start + chunk_size - 1
        headers = {"Range": "bytes={}-{}".format(start, stop)}

        response = pool.request(
            "GET",
            url,
            headers=headers,
            timeout=timeout,
        )
        if response.status == 200:
            raise ApiException(
                status=200,
                reason="The file server does not support multipart downloads.",
            )
        elif response.status != 206:
            raise ApiException(http_resp=response)

        # write to file
        fileobj.write(response.data)

        # parse content-range header (e.g. "bytes 0-3/7") for next iteration
        content_range = response.headers["Content-Range"]
        start, stop, total = [
            int(x) for x in CONTENT_RANGE_REGEXP.findall(content_range)[0]
        ]
        if stop + 1 >= total:
            break
        start += chunk_size

    return total


def upload_file(
    url: str,
    file_path: Path,
    chunk_size: int = 16777216,
    timeout: float = 5.0,
    pool: Optional[urllib3.PoolManager] = None,
    md5: Optional[bytes] = None,
) -> int:
    """Upload a file at specified file path to a url.

    The upload is accompanied by an MD5 hash so that the file server checks
    the integrity of the file.

    Args:
        url: The url to upload to.
        file_path: The file path to read data from.
        chunk_size: The size of the chunk in the streaming upload. Note that this
            function does not do multipart upload. Default: 16MB.
        timeout: The total timeout in seconds.
        pool: If not supplied, a default connection pool will be
            created with a retry policy of 3 retries after 1, 2, 4 seconds.
        md5: The MD5 digest (binary) of the file. Supply the MD5 if you already
            have access to it. Otherwise this function will compute it for you.

    Returns:
        The total number of uploaded bytes.

    Raises:
        IOError: Raised if the provided file is incompatible or empty.
        openapi_client.exceptions.ApiException: raised on unexpected server
            responses (HTTP status codes other than 206, 413, 429, 503)
        urllib3.exceptions.HTTPError: various low-level HTTP errors that persist
            after retrying: connection errors, timeouts, decode errors,
            invalid HTTP headers, payload too large (HTTP 413), too many
            requests (HTTP 429), service unavailable (HTTP 503)
    """
    # cast string to Path if necessary
    if isinstance(file_path, str):
        file_path = Path(file_path)

    # open the file
    with file_path.open("rb") as fileobj:
        size = upload_fileobj(
            url,
            fileobj,
            chunk_size=chunk_size,
            timeout=timeout,
            pool=pool,
            md5=md5,
        )

    return size


def _iter_chunks(fileobj: BinaryIO, chunk_size: int):
    """Yield chunks from a file stream"""
    assert chunk_size > 0
    while True:
        data = fileobj.read(chunk_size)
        if len(data) == 0:
            break
        yield data


def upload_fileobj(
    url: str,
    fileobj: BinaryIO,
    chunk_size: int = 16777216,
    timeout: float = 5.0,
    pool: Optional[urllib3.PoolManager] = None,
    md5: Optional[bytes] = None,
) -> int:
    """Upload a file object to a url.

    The upload is accompanied by an MD5 hash so that the file server checks
    the integrity of the file.

    Args:
        url: The url to upload to.
        fileobj: The (binary) file object to read from.
        chunk_size: The size of the chunk in the streaming upload. Note that this
            function does not do multipart upload. Default: 16MB.
        timeout: The total timeout in seconds.
        pool: If not supplied, a default connection pool will be
            created with a retry policy of 3 retries after 1, 2, 4 seconds.
        md5: The MD5 digest (binary) of the file. Supply the MD5 if you already
            have access to it. Otherwise this function will compute it for you.

    Returns:
        The total number of uploaded bytes.

    Raises:
        IOError: Raised if the provided file is incompatible or empty.
        openapi_client.exceptions.ApiException: raised on unexpected server
            responses (HTTP status codes other than 206, 413, 429, 503)
        urllib3.exceptions.HTTPError: various low-level HTTP errors that persist
            after retrying: connection errors, timeouts, decode errors,
            invalid HTTP headers, payload too large (HTTP 413), too many
            requests (HTTP 429), service unavailable (HTTP 503)
    """
    # There are two ways to upload in S3 (Minio):
    # - PutObject: put the whole object in one time
    # - multipart upload: requires presigned urls for every part
    # We can only do the first option as we have no other presigned urls.
    # So we take the first option, but we do stream the request body in chunks.

    # We will get hard to understand tracebacks if the fileobj is not
    # in binary mode. So use a trick to see if fileobj is in binary mode:
    if not isinstance(fileobj.read(0), bytes):
        raise IOError(
            "The file object is not in binary mode. Please open with mode='rb'."
        )

    # For computing the MD5 we need to do an extra pass on the file.
    if md5 is None:
        fileobj.seek(0)
        hasher = hashlib.md5()
        for chunk in _iter_chunks(fileobj, chunk_size=chunk_size):
            hasher.update(chunk)
        md5 = hasher.digest()
        file_size = fileobj.tell()
    else:
        file_size = fileobj.seek(0, 2)  # go to EOF

    if file_size == 0:
        raise IOError("The file object is empty.")

    if pool is None:
        pool = get_pool()

    fileobj.seek(0)
    iterable = _iter_chunks(fileobj, chunk_size=chunk_size)
    # Tested: both Content-Length and Content-MD5 are checked by Minio
    headers = {
        "Content-Length": str(file_size),
        "Content-MD5": base64.b64encode(md5).decode(),
    }
    response = pool.request(
        "PUT",
        url,
        body=iterable,
        headers=headers,
        timeout=timeout,
    )
    if response.status != 200:
        raise ApiException(http_resp=response)

    return file_size



# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from openapi_client.api_client import ApiClient
from openapi_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class InpyVersionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def inpy_versions_create(self, data, **kwargs):  # noqa: E501
        """inpy_versions_create  # noqa: E501

        Inpy is the service for preparing models to become usable by the Threedi calculation core. Updates in Inpy often result in updates in the calculation core.  This resource keeps track of updates to the Inpy service.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.inpy_versions_create(data, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param InpyVersion data: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: InpyVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.inpy_versions_create_with_http_info(data, **kwargs)  # noqa: E501

    def inpy_versions_create_with_http_info(self, data, **kwargs):  # noqa: E501
        """inpy_versions_create  # noqa: E501

        Inpy is the service for preparing models to become usable by the Threedi calculation core. Updates in Inpy often result in updates in the calculation core.  This resource keeps track of updates to the Inpy service.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.inpy_versions_create_with_http_info(data, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param InpyVersion data: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(InpyVersion, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'data'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method inpy_versions_create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'data' is set
        if self.api_client.client_side_validation and ('data' not in local_var_params or  # noqa: E501
                                                        local_var_params['data'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `data` when calling `inpy_versions_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in local_var_params:
            body_params = local_var_params['data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/inpy-versions/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InpyVersion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def inpy_versions_delete(self, id, **kwargs):  # noqa: E501
        """inpy_versions_delete  # noqa: E501

        Inpy is the service for preparing models to become usable by the Threedi calculation core. Updates in Inpy often result in updates in the calculation core.  This resource keeps track of updates to the Inpy service.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.inpy_versions_delete(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: A unique integer value identifying this inpy version. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.inpy_versions_delete_with_http_info(id, **kwargs)  # noqa: E501

    def inpy_versions_delete_with_http_info(self, id, **kwargs):  # noqa: E501
        """inpy_versions_delete  # noqa: E501

        Inpy is the service for preparing models to become usable by the Threedi calculation core. Updates in Inpy often result in updates in the calculation core.  This resource keeps track of updates to the Inpy service.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.inpy_versions_delete_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: A unique integer value identifying this inpy version. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method inpy_versions_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `inpy_versions_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/inpy-versions/{id}/', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def inpy_versions_list(self, **kwargs):  # noqa: E501
        """inpy_versions_list  # noqa: E501

        Inpy is the service for preparing models to become usable by the Threedi calculation core. Updates in Inpy often result in updates in the calculation core.  This resource keeps track of updates to the Inpy service.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.inpy_versions_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str threedi_version:
        :param str threedi_version__contains:
        :param str threedi_version__icontains:
        :param str threedi_version__in: Multiple values may be separated by commas.
        :param str threedi_version__startswith:
        :param str threedi_version__istartswith:
        :param str threedi_version__endswith:
        :param str threedi_version__regex:
        :param str threedicore_version:
        :param str threedicore_version__contains:
        :param str threedicore_version__icontains:
        :param str threedicore_version__in: Multiple values may be separated by commas.
        :param str threedicore_version__startswith:
        :param str threedicore_version__istartswith:
        :param str threedicore_version__endswith:
        :param str threedicore_version__regex:
        :param str slug:
        :param str slug__contains:
        :param str slug__icontains:
        :param str slug__in: Multiple values may be separated by commas.
        :param str slug__startswith:
        :param str slug__istartswith:
        :param str slug__endswith:
        :param str slug__regex:
        :param int limit: Number of results to return per page.
        :param int offset: The initial index from which to return the results.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: InlineResponse2003
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.inpy_versions_list_with_http_info(**kwargs)  # noqa: E501

    def inpy_versions_list_with_http_info(self, **kwargs):  # noqa: E501
        """inpy_versions_list  # noqa: E501

        Inpy is the service for preparing models to become usable by the Threedi calculation core. Updates in Inpy often result in updates in the calculation core.  This resource keeps track of updates to the Inpy service.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.inpy_versions_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str threedi_version:
        :param str threedi_version__contains:
        :param str threedi_version__icontains:
        :param str threedi_version__in: Multiple values may be separated by commas.
        :param str threedi_version__startswith:
        :param str threedi_version__istartswith:
        :param str threedi_version__endswith:
        :param str threedi_version__regex:
        :param str threedicore_version:
        :param str threedicore_version__contains:
        :param str threedicore_version__icontains:
        :param str threedicore_version__in: Multiple values may be separated by commas.
        :param str threedicore_version__startswith:
        :param str threedicore_version__istartswith:
        :param str threedicore_version__endswith:
        :param str threedicore_version__regex:
        :param str slug:
        :param str slug__contains:
        :param str slug__icontains:
        :param str slug__in: Multiple values may be separated by commas.
        :param str slug__startswith:
        :param str slug__istartswith:
        :param str slug__endswith:
        :param str slug__regex:
        :param int limit: Number of results to return per page.
        :param int offset: The initial index from which to return the results.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(InlineResponse2003, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'threedi_version',
            'threedi_version__contains',
            'threedi_version__icontains',
            'threedi_version__in',
            'threedi_version__startswith',
            'threedi_version__istartswith',
            'threedi_version__endswith',
            'threedi_version__regex',
            'threedicore_version',
            'threedicore_version__contains',
            'threedicore_version__icontains',
            'threedicore_version__in',
            'threedicore_version__startswith',
            'threedicore_version__istartswith',
            'threedicore_version__endswith',
            'threedicore_version__regex',
            'slug',
            'slug__contains',
            'slug__icontains',
            'slug__in',
            'slug__startswith',
            'slug__istartswith',
            'slug__endswith',
            'slug__regex',
            'limit',
            'offset'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method inpy_versions_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'threedi_version' in local_var_params and local_var_params['threedi_version'] is not None:  # noqa: E501
            query_params.append(('threedi_version', local_var_params['threedi_version']))  # noqa: E501
        if 'threedi_version__contains' in local_var_params and local_var_params['threedi_version__contains'] is not None:  # noqa: E501
            query_params.append(('threedi_version__contains', local_var_params['threedi_version__contains']))  # noqa: E501
        if 'threedi_version__icontains' in local_var_params and local_var_params['threedi_version__icontains'] is not None:  # noqa: E501
            query_params.append(('threedi_version__icontains', local_var_params['threedi_version__icontains']))  # noqa: E501
        if 'threedi_version__in' in local_var_params and local_var_params['threedi_version__in'] is not None:  # noqa: E501
            query_params.append(('threedi_version__in', local_var_params['threedi_version__in']))  # noqa: E501
        if 'threedi_version__startswith' in local_var_params and local_var_params['threedi_version__startswith'] is not None:  # noqa: E501
            query_params.append(('threedi_version__startswith', local_var_params['threedi_version__startswith']))  # noqa: E501
        if 'threedi_version__istartswith' in local_var_params and local_var_params['threedi_version__istartswith'] is not None:  # noqa: E501
            query_params.append(('threedi_version__istartswith', local_var_params['threedi_version__istartswith']))  # noqa: E501
        if 'threedi_version__endswith' in local_var_params and local_var_params['threedi_version__endswith'] is not None:  # noqa: E501
            query_params.append(('threedi_version__endswith', local_var_params['threedi_version__endswith']))  # noqa: E501
        if 'threedi_version__regex' in local_var_params and local_var_params['threedi_version__regex'] is not None:  # noqa: E501
            query_params.append(('threedi_version__regex', local_var_params['threedi_version__regex']))  # noqa: E501
        if 'threedicore_version' in local_var_params and local_var_params['threedicore_version'] is not None:  # noqa: E501
            query_params.append(('threedicore_version', local_var_params['threedicore_version']))  # noqa: E501
        if 'threedicore_version__contains' in local_var_params and local_var_params['threedicore_version__contains'] is not None:  # noqa: E501
            query_params.append(('threedicore_version__contains', local_var_params['threedicore_version__contains']))  # noqa: E501
        if 'threedicore_version__icontains' in local_var_params and local_var_params['threedicore_version__icontains'] is not None:  # noqa: E501
            query_params.append(('threedicore_version__icontains', local_var_params['threedicore_version__icontains']))  # noqa: E501
        if 'threedicore_version__in' in local_var_params and local_var_params['threedicore_version__in'] is not None:  # noqa: E501
            query_params.append(('threedicore_version__in', local_var_params['threedicore_version__in']))  # noqa: E501
        if 'threedicore_version__startswith' in local_var_params and local_var_params['threedicore_version__startswith'] is not None:  # noqa: E501
            query_params.append(('threedicore_version__startswith', local_var_params['threedicore_version__startswith']))  # noqa: E501
        if 'threedicore_version__istartswith' in local_var_params and local_var_params['threedicore_version__istartswith'] is not None:  # noqa: E501
            query_params.append(('threedicore_version__istartswith', local_var_params['threedicore_version__istartswith']))  # noqa: E501
        if 'threedicore_version__endswith' in local_var_params and local_var_params['threedicore_version__endswith'] is not None:  # noqa: E501
            query_params.append(('threedicore_version__endswith', local_var_params['threedicore_version__endswith']))  # noqa: E501
        if 'threedicore_version__regex' in local_var_params and local_var_params['threedicore_version__regex'] is not None:  # noqa: E501
            query_params.append(('threedicore_version__regex', local_var_params['threedicore_version__regex']))  # noqa: E501
        if 'slug' in local_var_params and local_var_params['slug'] is not None:  # noqa: E501
            query_params.append(('slug', local_var_params['slug']))  # noqa: E501
        if 'slug__contains' in local_var_params and local_var_params['slug__contains'] is not None:  # noqa: E501
            query_params.append(('slug__contains', local_var_params['slug__contains']))  # noqa: E501
        if 'slug__icontains' in local_var_params and local_var_params['slug__icontains'] is not None:  # noqa: E501
            query_params.append(('slug__icontains', local_var_params['slug__icontains']))  # noqa: E501
        if 'slug__in' in local_var_params and local_var_params['slug__in'] is not None:  # noqa: E501
            query_params.append(('slug__in', local_var_params['slug__in']))  # noqa: E501
        if 'slug__startswith' in local_var_params and local_var_params['slug__startswith'] is not None:  # noqa: E501
            query_params.append(('slug__startswith', local_var_params['slug__startswith']))  # noqa: E501
        if 'slug__istartswith' in local_var_params and local_var_params['slug__istartswith'] is not None:  # noqa: E501
            query_params.append(('slug__istartswith', local_var_params['slug__istartswith']))  # noqa: E501
        if 'slug__endswith' in local_var_params and local_var_params['slug__endswith'] is not None:  # noqa: E501
            query_params.append(('slug__endswith', local_var_params['slug__endswith']))  # noqa: E501
        if 'slug__regex' in local_var_params and local_var_params['slug__regex'] is not None:  # noqa: E501
            query_params.append(('slug__regex', local_var_params['slug__regex']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/inpy-versions/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2003',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def inpy_versions_partial_update(self, id, data, **kwargs):  # noqa: E501
        """inpy_versions_partial_update  # noqa: E501

        Inpy is the service for preparing models to become usable by the Threedi calculation core. Updates in Inpy often result in updates in the calculation core.  This resource keeps track of updates to the Inpy service.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.inpy_versions_partial_update(id, data, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: A unique integer value identifying this inpy version. (required)
        :param InpyVersion data: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: InpyVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.inpy_versions_partial_update_with_http_info(id, data, **kwargs)  # noqa: E501

    def inpy_versions_partial_update_with_http_info(self, id, data, **kwargs):  # noqa: E501
        """inpy_versions_partial_update  # noqa: E501

        Inpy is the service for preparing models to become usable by the Threedi calculation core. Updates in Inpy often result in updates in the calculation core.  This resource keeps track of updates to the Inpy service.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.inpy_versions_partial_update_with_http_info(id, data, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: A unique integer value identifying this inpy version. (required)
        :param InpyVersion data: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(InpyVersion, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'data'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method inpy_versions_partial_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `inpy_versions_partial_update`")  # noqa: E501
        # verify the required parameter 'data' is set
        if self.api_client.client_side_validation and ('data' not in local_var_params or  # noqa: E501
                                                        local_var_params['data'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `data` when calling `inpy_versions_partial_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in local_var_params:
            body_params = local_var_params['data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/inpy-versions/{id}/', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InpyVersion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def inpy_versions_read(self, id, **kwargs):  # noqa: E501
        """inpy_versions_read  # noqa: E501

        Inpy is the service for preparing models to become usable by the Threedi calculation core. Updates in Inpy often result in updates in the calculation core.  This resource keeps track of updates to the Inpy service.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.inpy_versions_read(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: A unique integer value identifying this inpy version. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: InpyVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.inpy_versions_read_with_http_info(id, **kwargs)  # noqa: E501

    def inpy_versions_read_with_http_info(self, id, **kwargs):  # noqa: E501
        """inpy_versions_read  # noqa: E501

        Inpy is the service for preparing models to become usable by the Threedi calculation core. Updates in Inpy often result in updates in the calculation core.  This resource keeps track of updates to the Inpy service.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.inpy_versions_read_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: A unique integer value identifying this inpy version. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(InpyVersion, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method inpy_versions_read" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `inpy_versions_read`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/inpy-versions/{id}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InpyVersion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def inpy_versions_update(self, id, data, **kwargs):  # noqa: E501
        """inpy_versions_update  # noqa: E501

        Inpy is the service for preparing models to become usable by the Threedi calculation core. Updates in Inpy often result in updates in the calculation core.  This resource keeps track of updates to the Inpy service.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.inpy_versions_update(id, data, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: A unique integer value identifying this inpy version. (required)
        :param InpyVersion data: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: InpyVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.inpy_versions_update_with_http_info(id, data, **kwargs)  # noqa: E501

    def inpy_versions_update_with_http_info(self, id, data, **kwargs):  # noqa: E501
        """inpy_versions_update  # noqa: E501

        Inpy is the service for preparing models to become usable by the Threedi calculation core. Updates in Inpy often result in updates in the calculation core.  This resource keeps track of updates to the Inpy service.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.inpy_versions_update_with_http_info(id, data, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: A unique integer value identifying this inpy version. (required)
        :param InpyVersion data: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(InpyVersion, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'data'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method inpy_versions_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `inpy_versions_update`")  # noqa: E501
        # verify the required parameter 'data' is set
        if self.api_client.client_side_validation and ('data' not in local_var_params or  # noqa: E501
                                                        local_var_params['data'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `data` when calling `inpy_versions_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in local_var_params:
            body_params = local_var_params['data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/inpy-versions/{id}/', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InpyVersion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
